/*@
  theory uses StackClass3, StackModel2 {
    Class: TYPE = StackClass3.StackClass3;
    Model: TYPE = StackModel2.StackModel;

    // the object invariant preserved by all public methods
    inv: PREDICATE(Class) =
      PRED(this: Class):
        this.null = FALSE AND this.stack.null = FALSE AND
        0 <= this.n AND this.n <= this.stack.length;

    // the abstraction function core
    abs: (Class, Base.int) -> Model;
    absAxiom: AXIOM 
      FORALL(c: Class, n: Base.int): 
        IF n <= 0 THEN
          abs(c, n) = StackModel2.empty
        ELSE
          abs(c, n) =
            StackModel2.push(abs(c, n-1), c.stack.value[n-1])
      ENDIF;        

    // the abstraction function
    abstract: Class -> Model = 
      LAMBDA(c: Class): abs(c, c.n);
    
    // the concretization relation used in the verification
    concrete: PREDICATE(Model, Class);
    concAxiom: AXIOM
      FORALL(m: Model, c: Class): 
       (concrete(m, c) <=> 
         (LET n = StackModel2.length(m) IN
           (n = c.n AND
           (FORALL(i:NAT): i < n => 
             StackModel2.get(m, i) = c.stack.value[n-i-1]))));
      
    // abstraction and concretization are equivalent
    // on all objects satisfying the invariant
    // (not proved, because structural induction not supported)
    abstractConcrete: FORMULA 
      FORALL(m: Model, c: Class): inv(c) =>
        (m = abstract(c) <=> concrete(m, c));
  }
@*/
public class StackClass3
{
  private int[] stack;
  private int n;

  public StackClass2() /*@
    assignable this;
    ensures inv(VAR this)
        AND StackModel2.isEmpty(abstract(VAR this));
  @*/
  {
    stack = new int[10];
    n = 0;
  }

  public boolean isEmpty() /*@
    requires inv(VAR this);
    ensures  inv(VAR this) 
        AND  (VALUE@NEXT = TRUE <=> 
                StackModel2.isEmpty(abstract(VAR this)));
  @*/
  {
    return n == 0;
  }

  public int top() /*@
    requires inv(VAR this) 
         AND NOT StackModel2.isEmpty(abstract(VAR this));
    ensures  inv(VAR this) 
        AND  VALUE@NEXT = StackModel2.top(abstract(VAR this));
  @*/
  {
    return stack[n-1];
  }

  public int pop() /*@
    requires inv(VAR this) 
         AND NOT StackModel2.isEmpty(abstract(VAR this));
    assignable n;
    ensures inv(VAR this)
        AND VALUE@NEXT = StackModel2.top(abstract(OLD this))
        AND StackModel2.equals(abstract(VAR this), 
              StackModel2.pop(abstract(OLD this)));
  @*/
  {
    int result = top();
    n = n-1;
    return result;
  }
  
  public void push(int v) /*@
    requires inv(VAR this) 
         AND (VAR n = (VAR stack).length => 
               2*(VAR n)+1 <= Base.MAX_INT);
    assignable stack, n;
    ensures inv(VAR this)
        AND StackModel2.equals(abstract(VAR this), 
              StackModel2.push(abstract(OLD this), VAR v));
  @*/
  {
    if (n == stack.length) 
      stack = resize();  
    stack[n] = v;
    n = n+1;
  }

  private int[] resize() /*@
    requires inv(VAR this) 
         AND 2*(VAR stack).length+1 <= Base.MAX_INT;
    ensures LET result = VALUE@NEXT IN
      result.null = FALSE AND 
      result.length > (OLD stack).length AND
      (FORALL(i: INT): 0 <= i AND i < VAR n =>
         result.value[i] = (OLD stack).value[i]);
  @*/
  {
    int[] stack0 = new int[2*stack.length+1];
    for (int i=0; i<n; i++) /*@
      invariant inv(VAR this) AND
        0 <= VAR i AND VAR i <= VAR n AND
        (VAR stack0).null = FALSE AND
        (VAR stack0).length > (OLD stack).length AND
        (FORALL(i: INT): 0 <= i AND i < VAR i =>
           (VAR stack0).value[i] = (OLD stack).value[i]);
      decreases VAR n - VAR i;
    @*/
      stack0[i] = stack[i];
    return stack0;
  }
}
  











