// ----------------------------------------------------------------------------
// VirtualDirectory.java
// A virtual directory stored in memory rather than on disk.
// $Id: VirtualDirectory.java,v 1.3 2011/05/18 14:05:56 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2010-, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.InOut;

import java.util.*;
import java.io.*;
import fmrisc.ProgramExplorer.*;

/**
 * 
 * A virtual directory stored in memory rather than on disk.
 *
 */
public final class VirtualDirectory
{
  // the name of the main file to be used for presentation
  public static String MAIN = "index.xhtml";
  
  // a mapping of names to file contents
  private Map<String, StringWriter> files;
  
  /***************************************************************************
   * Create a virtual directory.
   **************************************************************************/
  public VirtualDirectory()
  {
    files = new MapClass<String, StringWriter>();
  }
  
  /***************************************************************************
   * Create a file.
   * @param name the name of the file.
   * @return a writer for writing content to this file
   *         (null, if a file with the denoted name already exists).
   **************************************************************************/
  public PrintWriter create(String name)
  {
    if (files.containsKey(name)) return null;
    StringWriter writer = new StringWriter();
    files.put(name, writer);
    return new PrintWriter(writer);
  }
  
  /***************************************************************************
   * Get the content of a file.
   * @param name the name of the file.
   * @return its content (nul, if no file with the denoted name exists).
   **************************************************************************/
  public String read(String name)
  {
    StringWriter writer = files.get(name);
    if (writer == null) return null;
    return writer.toString();
  }
}
