// ----------------------------------------------------------------------------
// FormulaSymbol.java
// A symbol denoting a logical formula.
// $Id: FormulaSymbol.java,v 1.6 2010/11/04 17:00:22 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Semantics;

import java.io.PrintWriter;
import fmrisc.ProgramExplorer.Syntax.*;
import fmrisc.ProgramExplorer.Syntax.Logic.*;

/**
 * 
 * A symbol denoting a logical formula.
 *
 */
public class FormulaSymbol extends GlobalSymbolBase
{
  private Formula formula;
  private FormulaDefinition decl;
  
  /***************************************************************************
   * Construct formula symbol.
   * @param name the name of the symbol.
   * @param formula the formula identified by the symbol.
   * @param decl the declaration introducing the symbol.
   * @param theory the theory in which the symbol occurs (may be null)
   * @return the symbol.
   **************************************************************************/
  public static FormulaSymbol construct(Identifier name, Formula formula,
    FormulaDefinition decl, TheorySymbol theory)
  {
    return new FormulaSymbol(name, formula, decl, theory);
  }
  
  /***************************************************************************
   * Construct formula symbol.
   * @param name the name of the symbol.
   * @param formula the formula identified by the symbol.
   * @param decl the declaration introducing the symbol.
   * @param theory the theory in which the symbol occurs (may be null)
   **************************************************************************/
  protected FormulaSymbol(Identifier name, Formula formula,
    FormulaDefinition decl, TheorySymbol theory)
  {
    super(name, longName(name, theory));
    this.formula = formula;
    this.decl = decl;
  }
  
  /****************************************************************************
   * Get the long name of the formula.
   * @param name the formula's short name.
   * @param theory the theory of the formula.
   * @return the long name.
   ***************************************************************************/
  private static Name longName(Identifier name, TheorySymbol theory)
  {
    if (theory == null) return Name.construct(name);
    return Name.construct(theory.getLongName(), name);
  }
  
  /****************************************************************************
   * Get formula.
   * @return the formula.
   **************************************************************************/
  public Formula getFormula()
  {
    return formula;
  }
  
  /****************************************************************************
   * Get declaration.
   * @return the declaration.
   **************************************************************************/
  public FormulaDefinition getDeclaration()
  {
    return decl;
  }
  
  /***************************************************************************
   * Print symbol on output stream.
   * @param out the output stream.
   **************************************************************************/
  public void print(PrintWriter out)
  {
    out.print("formula ");
    getName().print(out);
  }
}

