// ----------------------------------------------------------------------------
// ValueSymbol.java
// A symbol denoting a logical value.
// $Id: ValueSymbol.java,v 1.7 2010/03/03 14:01:20 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Semantics;

import java.io.PrintWriter;

import fmrisc.ProgramExplorer.Syntax.*;
import fmrisc.ProgramExplorer.Syntax.Logic.*;

/**
 * 
 * A symbol denoting a logical value.
 *
 */
public final class ValueSymbol extends SymbolBase
{
  private Type type;
  private Declaration decl;
  
  /***************************************************************************
   * Construct value symbol.
   * @param name the name of the symbol.
   * @param type the type.
   * @param decl the declaration.
   * @return the symbol.
   **************************************************************************/
  public static ValueSymbol construct(Identifier name,
    Type type, Declaration decl)
  {
    return new ValueSymbol(name, type, decl);
  }
  
  /***************************************************************************
   * Construct value symbol.
   * @param name the name of the symbol.
   * @param type the type.
   * @param decl the declaration.
   **************************************************************************/
  private ValueSymbol(Identifier name, Type type, Declaration decl)
  {
    super(name);
    this.type = type;
    this.decl = decl;
  }
  
  /***************************************************************************
   * Get type.
   * @return the type.
   **************************************************************************/
  public Type getType()
  {
    return type;
  }
  
  /***************************************************************************
   * Get declaration.
   * @return the declaration.
   **************************************************************************/
  public Declaration getDeclaration()
  {
    return decl;
  }
  
  /***************************************************************************
   * Print symbol on output stream.
   * @param out the output stream.
   **************************************************************************/
  public void print(PrintWriter out)
  {
    out.print("value ");
    getName().print(out);
    out.print(": ");
    type.print(out);
  }
}
