// ----------------------------------------------------------------------------
// ASTBase.java
// Base class for abstract syntax trees.
// $Id: ASTBase.java,v 1.12 2011/09/30 15:47:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax;

import java.io.*;

import fmrisc.ProgramExplorer.Syntax.ASTPrinter.PrintStatementSpec;

/**
 * Base class for abstract syntax trees.
 */
public abstract class ASTBase implements AST
{
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
  }
  
  /****************************************************************************
   * Visit a sequence of abstract syntax trees.
   * @param trees the abstract syntax trees that are to be visited.
   * @param visitor the visitor to visit the trees
   ***************************************************************************/
  final public static void accept(AST[] trees, ASTVisitorOld visitor)
  {
    for (AST tree : trees)
      tree.accept(visitor);
  }
  
  /****************************************************************************
   * Visit a sequence of abstract syntax trees.
   * @param trees the abstract syntax trees that are to be visited.
   * @param visitor the visitor to visit the trees
   ***************************************************************************/
  final public static void accept(AST[] trees, ASTVisitor visitor)
  {
    for (AST tree : trees)
      tree.accept(visitor);
  }
  
  /****************************************************************************
   * Get string representation of tree (including command annotations).
   * @return the string representation.
   ***************************************************************************/
  public final String toString()
  {
    StringWriter s = new StringWriter();
    PrintWriter out = new PrintWriter(s);
    print(out);
    out.flush();
    return s.toString();
  }
  
  /****************************************************************************
   * Get string representation of tree (excluding command annotations).
   * @return the string representation.
   ***************************************************************************/
  public final String toStringCore()
  {
    StringWriter s = new StringWriter();
    PrintWriter out = new PrintWriter(s);
    printCore(out);
    out.flush();
    return s.toString();
  }
  
  /****************************************************************************
   * Print tree on writer (including command annotations).
   * @param out the writer to be used for printing.
   ***************************************************************************/
  public final void print(PrintWriter out)
  {
    ASTPrinter.print(this, out, PrintStatementSpec.NONE, true);
  }
  
  /****************************************************************************
   * Print tree on writer (excluding command annotations).
   * @param out the writer to be used for printing.
   ***************************************************************************/
  public final void printCore(PrintWriter out)
  {
    ASTPrinter.print(this, out, PrintStatementSpec.NONE, false);
  }
}
