// ----------------------------------------------------------------------------
// BinaryAtomicFormula.java
// Base class of atomic formulas with binary operators.
// $Id: BinaryAtomicFormula.java,v 1.5 2011/09/30 15:47:33 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the formulas of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * 
 * Base class of atomic formulas with binary operators.
 *
 */
public abstract class BinaryAtomicFormula extends BinaryExpression 
  implements Formula
{
  public final static int precedence = 60; // see SpecLang.g
  
  /****************************************************************************
   * Construct binary formula.
   * @param first the first term.
   * @param second the second term.
   ***************************************************************************/
  protected BinaryAtomicFormula(Term first, Term second)
  {
    super(first, second);
  }
  
  /***************************************************************************
   * Get first subterm.
   * @return the first subterm.
   **************************************************************************/
  public Term getFirst()
  {
    return (Term)first;
  }
  
  /***************************************************************************
   * Get second subterm.
   * @return the second subterm.
   **************************************************************************/
  public Term getSecond()
  {
    return (Term)second;
  }
  
  /***************************************************************************
   * Get precedence value of the expression operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    return precedence;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    super.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}


