// ----------------------------------------------------------------------------
// ForallFormula.java
// A universally quantified formula.
// $Id: ForallFormula.java,v 1.4 2011/09/30 15:47:32 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.ASTVisitor;

/**
 * 
 * A universally quantified formula.
 *
 */
public final class ForallFormula extends QuantifiedFormula
{
  /***************************************************************************
   * Construct a universally quantified formula.
   * @param vars the bound variables of the formula.
   * @param body the body of the formula.
   * @return the formula.
   **************************************************************************/
  public static ForallFormula construct(TypedIdentifier[] vars, Formula body)
  {
    return new ForallFormula(vars, body);
  }
  
  /***************************************************************************
   * Construct a universally quantified formula.
   * @param vars the bound variables of the formula.
   * @param body the body of the formula.
   **************************************************************************/
  private ForallFormula(TypedIdentifier[] vars, Formula body)
  {
    super(vars, body);
  }
  
  /***************************************************************************
   * Get string representation of quantifier.
   * @return string representation of the quantifier.
   **************************************************************************/
  public String getQuantifier()
  {
    return "FORALL";
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
