// ----------------------------------------------------------------------------
// FunctionApplication.java
// A function application.
// $Id: FunctionApplication.java,v 1.9 2017/07/04 08:04:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * 
 * A function application.
 *
 */
public final class FunctionApplication extends TermApplication implements Term
{
  public static final int precedence = 80; // see SpecLang.g
  
  private Type type = null; // the type annotation
  
  /****************************************************************************
   * Set type annotation of term.
   * @param type the type annotation.
   ***************************************************************************/
  public void setType(Type type)
  {
    this.type = type;
  }
  
  /****************************************************************************
   * Set type annotation of term.
   * @return the type annotation.
   ***************************************************************************/
  public Type getType()
  {
    return type;
  }
  
  /***************************************************************************
   * Construct application expression.
   * @param fun the function that is being applied.
   * @param args the arguments to which the function is applied.
   * @return the expression.
   **************************************************************************/
  public static FunctionApplication construct (Term fun, Term[] args)
  {
    return new FunctionApplication(fun, args);
  }
  
  /***************************************************************************
   * Construct application expression.
   * @param fun the function that is being applied.
   * @param args the arguments to which the function is applied.
   **************************************************************************/
  private FunctionApplication(Term fun, Term[] args)
  {
    super(fun, args);
  }
  
  /***************************************************************************
   * Get precedence value of the formula operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    return precedence;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}

