// ----------------------------------------------------------------------------
// FunctionType.java
// A function type.
// $Id: FunctionType.java,v 1.7 2017/07/04 08:04:38 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the types of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.ASTVisitorOld;
import fmrisc.ProgramExplorer.Syntax.ASTVisitor;

/**
 * 
 * A function type.
 *
 */
public final class FunctionType extends TypeBase
{  
  private static final int precedence = 0; // lowest precedence, see SpecLang.g
  private final Type[] domain;
  private final Type range;
  
  /****************************************************************************
   * Construct array type.
   * @param domain the domain types.
   * @param range the range type.
   * @return the type.
   ***************************************************************************/
  public static FunctionType construct(Type[] domain, Type range)
  {
    return new FunctionType(domain, range);
  }
  
  /****************************************************************************
   * Construct array type.
   * @param domain the domain types.
   * @param range the range type.
   ***************************************************************************/
  private FunctionType(Type[] domain, Type range)
  {
    this.domain = domain;
    this.range = range;
  }
  
  /****************************************************************************
   * Get domain types.
   * @return the domain types.
   ***************************************************************************/
  public Type[] getDomain()
  {
    return domain;
  }
  
  /****************************************************************************
   * Get range type.
   * @return the range type.
   ***************************************************************************/
  public Type getRange()
  {
    return range;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
    accept(domain, visitor);
    range.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    accept(domain, visitor);
    range.accept(visitor);
  }
  
  /***************************************************************************
   * Get precedence value of the type operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    return precedence;
  }
}

