// ----------------------------------------------------------------------------
// IfThenElseExpression.java
// Base class of a conditional expression.
// $Id: IfThenElseExpression.java,v 1.5 2011/09/30 15:47:32 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.ASTVisitorOld;
import fmrisc.ProgramExplorer.Syntax.ASTVisitor;

/**
 * 
 * Base class of a conditional expression.
 *
 */
public abstract class IfThenElseExpression extends ExpressionBase 
{
  public final static String ifKeyword = "IF";
  public final static String thenKeyword = "THEN";
  public final static String elsifKeyword = "ELSIF";
  public final static String elseKeyword = "ELSE";
  public final static String endifKeyword = "ENDIF";
  
  protected final Formula condition;
  protected final Expression thenbranch;
  protected final Expression elsebranch;
  
  /***************************************************************************
   * Construct a conditional expression.
   * @param cond the condition.
   * @param tbranch the "then" branch.
   * @param ebranch the "else" branch.
   **************************************************************************/
  protected IfThenElseExpression(Formula cond, 
    Expression tbranch, Expression ebranch)
  {
    this.condition = cond;
    this.thenbranch = tbranch;
    this.elsebranch = ebranch;
  }
  
  /***************************************************************************
   * Get condition.
   * @return the condition.
   **************************************************************************/
  public Formula getCondition()
  {
    return condition;
  }
  
  /***************************************************************************
   * Get "then" branch.
   * @return the "then" branch.
   **************************************************************************/
  public Expression getThenBranch()
  {
    return thenbranch;
  }
  
  /***************************************************************************
   * Get "else" branch.
   * @return the "else" branch.
   **************************************************************************/
  public Expression getElseBranch()
  {
    return elsebranch;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
    condition.accept(visitor);
    thenbranch.accept(visitor);
    elsebranch.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    condition.accept(visitor);
    thenbranch.accept(visitor);
    elsebranch.accept(visitor);
  }
}
