// ----------------------------------------------------------------------------
// IfThenElseTerm.java
// Base class of a conditional term.
// $Id: IfThenElseTerm.java,v 1.5 2011/09/30 15:47:33 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.ASTVisitor;

/**
 * 
 * Base class of a conditional term.
 *
 */
public final class IfThenElseTerm extends IfThenElseExpression 
  implements Term
{
  public final static int precedence  = -1; // ??? 
  
  private Type type = null; // the type annotation
  
  /****************************************************************************
   * Set type annotation of term.
   * @param type the type annotation.
   ***************************************************************************/
  public void setType(Type type)
  {
    this.type = type;
  }
  
  /****************************************************************************
   * Set type annotation of term.
   * @return the type annotation.
   ***************************************************************************/
  public Type getType()
  {
    return type;
  }
  
  /***************************************************************************
   * Construct a conditional term.
   * @param cond the condition.
   * @param tbranch the "then" branch.
   * @param ebranch the "else" branch.
   * @return the conditional term.
   **************************************************************************/
  public static IfThenElseTerm construct (Formula cond, Term tbranch, Term ebranch)
  {
    return new IfThenElseTerm(cond, tbranch, ebranch);
  }
  
  /***************************************************************************
   * Construct a conditional term.
   * @param cond the condition.
   * @param tbranch the "then" branch.
   * @param ebranch the "else" branch.
   **************************************************************************/
  private IfThenElseTerm(Formula cond, Term tbranch, Term ebranch)
  {
    super(cond, tbranch, ebranch);
  }
  
  /***************************************************************************
   * Get "then" branch.
   * @return the "then" branch.
   **************************************************************************/
  public Term getThenBranch()
  {
    return (Term)thenbranch;
  }
  
  /***************************************************************************
   * Get "else" branch.
   * @return the "else" branch.
   **************************************************************************/
  public Term getElseBranch()
  {
    return (Term)elsebranch;
  }
  
  /***************************************************************************
   * Get precedence value of the term operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    return precedence;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
