// ----------------------------------------------------------------------------
// PreVariable.java
// A reference to a program variable in the pre-state.
// $Id: PreVariable.java,v 1.9 2017/07/04 08:04:38 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.ASTVisitor;
import fmrisc.ProgramExplorer.Syntax.Name;

/**
 * 
 * A reference to a program variable in the pre-state.
 *
 */
public final class PreVariable extends ProgramVariableBase
{ 
  public static final String keyword = "OLD";
  
  /***************************************************************************
   * Construct a reference to a program variable in the pre-state.
   * @param name the name of the variable.
   * @return the variable.
   **************************************************************************/
  public static PreVariable construct(Name name)
  {
    return new PreVariable(name);
  }
  
  /***************************************************************************
   * Construct a reference to a program variable in the pre-state.
   * @param name the name of the variable.
   **************************************************************************/
  private PreVariable(Name name)
  {
    super(name);
  }
  
  /***************************************************************************
   * Get string representation of keyword.
   * @return string representation of the keyword.
   **************************************************************************/
  public String getKeyword()
  {
    return keyword;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
