// ----------------------------------------------------------------------------
// QuantifiedExpression.java
// Base class of quantified expressions.
// $Id: QuantifiedExpression.java,v 1.7 2011/09/30 15:47:32 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * 
 * Base class of quantified expressions.
 *
 */
public abstract class QuantifiedExpression extends ExpressionBase
{
  public final static int precedence  = 0; // see SpecLang.g
  
  protected final TypedIdentifier[] variables;
  protected final Expression body;
  
  /***************************************************************************
   * Construct a quantified expression.
   * @param variables the bound variables of the expression.
   * @param body the body of the expression.
   **************************************************************************/
  protected QuantifiedExpression(TypedIdentifier[] variables, Expression body)
  {
    this.variables = variables;
    this.body = body;
  }
  
  /***************************************************************************
   * Get bound variables of the expression.
   * @return the bound variables.
   **************************************************************************/
  public TypedIdentifier[] getVariables()
  {
    return variables;
  }
  
  /***************************************************************************
   * Get body of expression.
   * @return the body.
   **************************************************************************/
  public Expression getBody()
  {
    return body;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
    accept(variables, visitor);
    body.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    accept(variables, visitor);
    body.accept(visitor);
  }
  
  /***************************************************************************
   * Get precedence value of the expression operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    return precedence;
  }
  
  /***************************************************************************
   * Get string representation of quantifier.
   * @return string representation of the quantifier.
   **************************************************************************/
  public abstract String getQuantifier();
}
