// ----------------------------------------------------------------------------
// SelectionTerm.java
// A term from which a component is selected.
// $Id: SelectionTerm.java,v 1.6 2011/09/30 15:47:32 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the Formulas of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;

/**
 * 
 * A term from which a component is selected.
 *
 */
public final class SelectionTerm extends TermBase implements Formula
{
  private static final int precedence = 70; // see SpecLang.g
  private final Term base;
  private final Selector selector;
  
  /****************************************************************************
   * Construct selection term.
   * @param base the base term.
   * @param selector the selector.
   * @return the term.
   ***************************************************************************/
  public static SelectionTerm construct(Term base, Selector selector)
  {
    return new SelectionTerm(base, selector);
  }
  
  /****************************************************************************
   * Construct selection term.
   * @param base the base term.
   * @param selector the selector.
   ***************************************************************************/
  private SelectionTerm(Term base, Selector selector)
  {
    this.base = base;
    this.selector = selector;
  }
  
  /****************************************************************************
   * Get base term.
   * @return the base term.
   ***************************************************************************/
  public Term getBase()
  {
    return base;
  }
  
  /****************************************************************************
   * Get selector.
   * @return the selector.
   ***************************************************************************/
  public Selector getSelector()
  {
    return selector;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
    base.accept(visitor);
    selector.accept(visitor);
  }
  
  /***************************************************************************
   * Get precedence value of the expression operator 
   * (higher precedence value means higher binding power)
   **************************************************************************/
  public int getPrecedence()
  {
    return precedence;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    base.accept(visitor);
    selector.accept(visitor);
  }
}
