// ----------------------------------------------------------------------------
// SimilarFormula.java
// A state similarity (equality up to result value).
// $Id: SimilarFormula.java,v 1.4 2017/07/04 08:04:38 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the Formulas of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.ASTVisitorOld;
import fmrisc.ProgramExplorer.Syntax.ASTVisitor;

/**
 * 
 * A state similarity (equality up to result value).
 *
 */
public final class SimilarFormula extends BinaryAtomicFormula
{
  public final static String operator = "~";
  
  /****************************************************************************
   * Construct a similarity.
   * @param first the first (left) part.
   * @param second the right (second) part.
   * @return the formula.
   ***************************************************************************/
  public static SimilarFormula construct(Term first, Term second)
  {
    return new SimilarFormula(first, second);
  }
  
  /****************************************************************************
   * Construct a similarity.
   * @param first the first (left) part.
   * @param second the right (second) part.
   ***************************************************************************/
  private SimilarFormula(Term first, Term second)
  {
    super(first, second);
  }
  
  /***************************************************************************
   * Get textual representation of operator.
   **************************************************************************/
  public String getOperator()
  {
    return operator;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}


