// ----------------------------------------------------------------------------
// TermApplication.java
// An application of one term to some other term(s).
// $Id: TermApplication.java,v 1.4 2011/09/30 15:47:33 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.ASTVisitor;

/**
 * 
 * An application of one term to some other term(s).
 *
 */
public abstract class TermApplication extends ApplicationExpression
{  
  /***************************************************************************
   * Construct term application.
   * @param fun the function that is being applied.
   * @param args the arguments to which the function is applied.
   **************************************************************************/
  protected TermApplication(Term fun, Term[] args)
  {
    super(fun, args);
  }
  
  /***************************************************************************
   * Get the function.
   * @return the function.
   **************************************************************************/
  public Term getFunction()
  {
    return (Term)fun;
  }
  
  /***************************************************************************
   * Get the arguments.
   * @return the arguments.
   **************************************************************************/
  public Term[] getArguments()
  {
    return (Term[])args;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}


