// ----------------------------------------------------------------------------
// ValueDefinition.java
// The definition of a value.
// $Id: ValueDefinitionClass.java,v 1.4 2011/09/30 15:47:33 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Logic;

import fmrisc.ProgramExplorer.Syntax.*;
import fmrisc.ProgramExplorer.Semantics.*;

/**
 * 
 * The definition of a value.
 *
 */
public final class ValueDefinitionClass extends DefinitionBase
  implements ValueDefinition
{
  /****************************************************************************
   * Create new definition of a constant denoting a value.
   * @param name the name of the constant.
   * @param value its value.
   * @return the definition.
   ***************************************************************************/
  public static ValueDefinitionClass construct(Identifier name, Term value)
  {
    return new ValueDefinitionClass(name, value);
  }
    
  /****************************************************************************
   * Create new definition of a constant denoting a value.
   * @param name the name of the constant.
   * @param value its value
   * @return the definition
   ***************************************************************************/
  protected ValueDefinitionClass(Identifier name, Term value)
  {
    super(name, value);
  }
  
  /***************************************************************************
   * Get value of the definition.
   * @return the value.
   **************************************************************************/
  public Term getValue()
  {
    return (Term)value;
  }
  
  /***************************************************************************
   * Get symbol introduced by declaration.
   * @return the symbol.
   **************************************************************************/
  public ValueSymbol getSymbol()
  {
    return (ValueSymbol)name.getSymbol();
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    super.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}

