// ----------------------------------------------------------------------------
// NewAssignmenStatement.java
// An constructor call statement with the result value assigned to a variable.
// $Id: AssignNewStatement.java,v 1.4 2017/07/04 08:04:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import java.util.*;
import fmrisc.ProgramExplorer.Syntax.*;

/**
 * A constructor call statement with the result value assigned to a variable.
 */
public final class AssignNewStatement extends AssignCallStatement
{
  /****************************************************************************
   * Construct a call statement with a result value assigned to a variable.
   * @param lval the left value taking the result (may be null)
   * @param type the type name
   * @param args the type arguments
   * @return the statement.
   ***************************************************************************/
  public static AssignNewStatement construct
    (LeftValue lval, Name type, Vector<ValueExpression> args)
  {
    return new AssignNewStatement(lval, type, 
        args.toArray(new ValueExpression[args.size()]));
  }
  
  /****************************************************************************
   * Construct a call statement with a result value assigned to a variable.
   * @param lval the left value taking the result (may be null)
   * @param type the type name
   * @param args the type arguments
   * @return the statement
   ***************************************************************************/
  public static AssignNewStatement construct
    (LeftValue lval, Name type, ValueExpression[] args)
  {
    return new AssignNewStatement(lval, type, args);
  }
  
  /****************************************************************************
   * Construct a call statement with a result value assigned to a variable.
   * @param lval the left value taking the result
   * @param type the type name
   * @param args the type arguments
   ***************************************************************************/
  private AssignNewStatement(LeftValue lval, Name type, ValueExpression[] args)
  {
    super(lval, type, args);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
