// ----------------------------------------------------------------------------
// LoopStatementBase.java
// The base class for loop statements.
// $Id: LoopStatementBase.java,v 1.5 2011/09/30 15:47:35 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import fmrisc.ProgramExplorer.Syntax.ASTVisitorOld;
import fmrisc.ProgramExplorer.Syntax.ASTVisitor;

/**
 * 
 * The base class for loop statements.
 * 
 */
public abstract class LoopStatementBase extends StatementBase 
  implements LoopStatement
{
  private ProgramAnnotation loopAnnotation;
  
  /***************************************************************************
   * Set the loop annotation for this item.
   * @param annotation the annotation.
   **************************************************************************/
  public void setLoopAnnotation(ProgramAnnotation annotation)
  {
    this.loopAnnotation = annotation;
  }
  
  /***************************************************************************
   * Get the loop annotation for this item.
   * @return the annotation (null, if there is none).
   **************************************************************************/
  public ProgramAnnotation getLoopAnnotation()
  {
    return loopAnnotation;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    super.accept(visitor);
    if (loopAnnotation != null) loopAnnotation.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    if (loopAnnotation != null) loopAnnotation.accept(visitor);
  }
}
