// ----------------------------------------------------------------------------
// NamedType.java
// A named (user-defined) type.
// $Id: NamedType.java,v 1.5 2017/07/04 08:04:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2008, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import fmrisc.ProgramExplorer.Semantics.*;
import fmrisc.ProgramExplorer.Syntax.*;

/**
 * A named (user-defined) type
 */
public final class NamedType extends ASTProgramBase implements TypeExpression
{
  public final Name name;
  
  /****************************************************************************
   * Construct a named type.
   * @param name the name of the type
   * @return the type.
   ***************************************************************************/
  public static NamedType construct(Name name)
  {
    return new NamedType(name);
  } 
  
  /****************************************************************************
   * Construct a named type.
   * @param name the name of the type
   ***************************************************************************/
  private NamedType(Name name)
  {
    this.name = name;
  } 

  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    boolean done = visitor.visit(this);
    if (done) return;
    name.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
  
  /***************************************************************************
   * Accept visitor for a visit to the children of this node.
   * @param visitor the visitor who is accepted by the children of this node.
   **************************************************************************/
  public void acceptChildren(ASTVisitor visitor)
  {
    super.acceptChildren(visitor);
    name.accept(visitor);
  }
  
  /****************************************************************************
   * Get symbol of class denoted by name.
   * @return the class symbol.
   ***************************************************************************/
  public ClassSymbol getSymbol()
  {
    Identifier[] idents = name.idents;
    int n = idents.length;
    return (ClassSymbol)idents[n-1].getSymbol();
  }
}
