// ----------------------------------------------------------------------------
// ProgramAnnotation.java
// A program annotation.
// $Id: ProgramAnnotationBase.java,v 1.6 2011/09/30 15:47:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2009, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Syntax.Program;

import fmrisc.ProgramExplorer.Syntax.*;
import fmrisc.ProgramExplorer.InOut.*;

/**
 * 
 * A program annotation.
 *
 */
public abstract class ProgramAnnotationBase extends ASTProgramBase 
  implements ProgramAnnotation
{
  // the plain annotation text
  private final String text;  
  
  // the position in the source
  private SourcePosition position = null; 
  
  /****************************************************************************
   * Construct annotation with denoted text.
   * @param text the annotation text.
   ***************************************************************************/
  protected ProgramAnnotationBase(String text)
  {
    this.text = text;
  }

  /****************************************************************************
   * Get annotation text.
   * @return the annotation text.
   ***************************************************************************/
  public final String getText()
  {
    return text;
  }
  
  /***************************************************************************
   * Set the position of this node in the source code.
   * @param position the source code position.
   **************************************************************************/
  public void setPosition(SourcePosition position)
  {
    this.position = position;
  }
  
  /***************************************************************************
   * Get the position of this node in the source code (may be null).
   * @return the source code position.
   **************************************************************************/
  public SourcePosition getPosition()
  {
    return position;
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitorOld visitor)
  {
    super.accept(visitor);
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   **************************************************************************/
  public void accept(ASTVisitor visitor)
  {
    visitor.visit(this);
  }
}
