// ----------------------------------------------------------------------------
// AllStrategy.java
// A strategy for folders that resumes all new tasks in folder.
// $Id: AllNewStrategy.java,v 1.5 2011/03/28 16:32:29 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2010-, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.ewuni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Tasks;

/**
 * 
 * A strategy for folders that resumes all new tasks in folder.
 *
 */
public class AllNewStrategy implements Strategy
{
  /****************************************************************************
   * True if this strategy is applicable to the denoted task.
   * @param task a task
   * @return true iff apply() may be invoked on task.
   ***************************************************************************/
  public boolean isApplicable(Task task)
  {
    // must be able to apply the RISC ProofNavigator
    return task instanceof TaskFolder;
  }
  
  /****************************************************************************
   * Apply this strategy to a task to which it is applicable.
   * @param task a task to which the task is applicable.
   ***************************************************************************/
  public void apply(Task task)
  {
    TaskFolder folder = (TaskFolder)task;
    
    // resume all new tasks in folder
    Task[] tasks = folder.getTasks();
    for (Task t : tasks)
    {
      // apply resume() to new appropriate tasks
      Task.Status status = t.getStatus();
      if (status == Task.Status.NEW && t.resumeOnNew()) t.resume();
    }
    
    // apply strategy recursively to subfolders
    TaskFolder[] folders = folder.getFolders();
    for (TaskFolder f : folders)
      apply(f);
    
    // recompute folder status
    folder.computeStatus();
  }
}
