// ----------------------------------------------------------------------------
// ClassicalTaskBase.java
// Base of a task that can be translated to a classical proving problem.
// $Id: ClassicalTaskBase.java,v 1.2 2010/11/03 17:06:37 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2010-, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.ewuni-linz.ac.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Tasks;

import java.io.File;

import fmrisc.ProgramExplorer.InOut.*;
import fmrisc.ProgramExplorer.Proving.*;

/**
 * 
 * Base of a task that can be translated to a classical proving problem.
 *
 */
public abstract class ClassicalTaskBase extends ProofNavigatorTaskBase 
  implements ClassicalTask
{
  private ProofNavigatorProblem problem;
  
  /****************************************************************************
   * Construct task with denoted name and status NEW
   * @param name the name of the task
   * @param optional is this task optional?
   * @param position a related source position (may be null)
   * @param parent the parent of the directory created for writing 
   *        persistent information related to this task.
   ***************************************************************************/
  protected ClassicalTaskBase(String name, boolean optional,
    SourcePosition position, File parent, Strategy strategy)
  {
    super(name, optional, position, parent, strategy);
    problem = null;
  }
  
  /****************************************************************************
   * Translate task into a problem for the RISC ProofNavigator.
   * @return the translation.
   ***************************************************************************/
  public ProofNavigatorProblem proofNavigatorProblem()
  {
    // avoid repeated problem construction
    if (problem != null) return problem;
    ClassicalProblem cproblem = classicalProblem();
    problem = cproblem.proofNavigatorProblem(getDirectory());
    return problem;
  }
  
  /****************************************************************************
   * Reset the task to its initial (new) state.
   ***************************************************************************/
  public void reset()
  {
    problem = null;
    super.reset();
  }
}
