// ----------------------------------------------------------------------------
// ManualStrategy.java
// A strategy that attempts interactive proving.
// $Id: ManualStrategy.java,v 1.3 2011/04/07 13:25:13 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.jku.at>
// Copyright (C) 2010-, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.jku.at
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------
package fmrisc.ProgramExplorer.Tasks;

import fmrisc.ProgramExplorer.Proving.*;

/**
 * 
 * A strategy that attempts interactive proving.
 *
 */
public class ManualStrategy implements Strategy
{
  /****************************************************************************
   * True if this strategy is applicable to the denoted task.
   * @param task a task
   * @return true iff apply() may be invoked on task.
   ***************************************************************************/
  public boolean isApplicable(Task task)
  {
    // must be able to apply the RISC ProofNavigator
    return task instanceof ProofNavigatorTask;
  }
  
  /****************************************************************************
   * Apply this strategy to a task to which it is applicable.
   * @param task a task to which the task is applicable.
   ***************************************************************************/
  public void apply(Task task)
  {
    // task may be closed
    if (task.isFinal()) return;
    
    // generate ProofNavigatorProblem
    ProofNavigatorTask task0 = (ProofNavigatorTask)task; 
    ProofNavigatorProblem problem = task0.proofNavigatorProblem();
        
    // if task is new, attempt strategy solution
    Task.Status status = task.getStatus();
    if (status == Task.Status.NEW)
    {
      problem.proveStrategy(task);
      if (task.isFinal()) return;
    }
    
    // attempt interactive solution
    problem.proveManual(task);
  }
}
