// ----------------------------------------------------------------------------
// AutoStar.java
// The "autostar" command.
// $Id: AutoStar.java,v 1.4 2009/10/19 16:16:10 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Commands;

import java.io.*;
import org.w3c.dom.*;

import fmrisc.ProofNavigator.Proving.*;

/**
 * 
 * command "autostar": apply auto to current node and its successor siblings.
 *
 */
public final class AutoStar extends ProofCommandBase
{
  public final static String Name = "autostar";
  private static ProofCommand auto = new Auto(null);

  /***************************************************************************
   * Create a "autostar" command.
   **************************************************************************/
  public AutoStar()
  {
    super(Name);
  }
  
  /****************************************************************************
   * Process command "autostar": 
   * @param state the proof state to which the command is applied.
   * @return null or array of single new proof state.
   ***************************************************************************/
  protected ProofState[] processCore(ProofState state)
  {
    ProofState parent = state.getParent();
    if (parent == null) return null;
    ProofState[] siblings = parent.getChildren();
    boolean found = false;
    int n = siblings.length;
    for (int i=0; i<n; i++)
    {
      ProofState sibling = siblings[i];
      if (sibling == state) found = true;
      if (found && !sibling.isClosed()) 
        auto.process(sibling);
    }
    return null;
  }
  
  /***************************************************************************
   * Convert DOM node to command.
   * @param node the DOM representation of the command.
   * @return the command (null, if an error occured).
   **************************************************************************/
  public static Command newCommand(Node node)
  {
    return new Decompose();
  }
  
  /***************************************************************************
   * Prints text representation on out (without new line termination).
   * @param out the stream on which the text is written
   **************************************************************************/
  public void printCore(PrintWriter out)
  {
    out.print(getName());
  }
}
