// ----------------------------------------------------------------------------
// FormulaC.java
// The "formula" command.
// $Id: FormulaC.java,v 1.10 2011/07/18 13:56:15 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Commands;

import java.io.*;

import fmrisc.ProofNavigator.*;
import fmrisc.ProofNavigator.Communication.*;
import fmrisc.ProofNavigator.Semantics.*;
import fmrisc.ProofNavigator.Syntax.*;

/**
 * 
 * Command "formula": print value of formula identifier.
 *
 */
public final class FormulaC extends CommandBase
{
  public final static String Name = "printf";
  private Identifier ident;
  
  /***************************************************************************
   * Create a "formula" command.
   * @param ident identifier of denoted formula
   **************************************************************************/
  public FormulaC(Identifier ident)
  {
    super(Name);
    this.ident = ident;
  }
  
  /****************************************************************************
   * Process command "formula": print value of formula identifier.
   ***************************************************************************/
  public void process()
  { 
    Environment env = getEnvironment();
    FormulaSymbol symbol = env.getFormulaSymbol(ident);
    if (symbol == null)
    {
      error("there is no formula named " + ident.toString() + 
              " visible in current environment");
      return;
    }
    PrintWriter out = State.getSystemOut();
    PrettyPrinter printer = new PrettyPrinter(out);
    printer.print(ident.toString());
    printer.print(": FORMULA ");
    printer.changeLevel(true);
    printer.newLine();
    printer.print(symbol.getFormula());
    out.println(".");
  }
  
  /***************************************************************************
   * Prints text representation on out (without new line termination).
   * @param out the stream on which the text is written
   **************************************************************************/
  public void printCore(PrintWriter out)
  {
    out.print(getName());
    out.print(" ");
    ident.print(out);
  }
}
