// ----------------------------------------------------------------------------
// ProofC.java
// The "proof" command.
// $Id: ProofC.java,v 1.10 2008/10/13 09:31:59 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Commands;

import java.io.PrintWriter;

import fmrisc.ProofNavigator.*;
import fmrisc.ProofNavigator.Proving.*;
import fmrisc.ProofNavigator.Semantics.*;
import fmrisc.ProofNavigator.Syntax.*;

/**
 * 
 * Command "proof": print proof tree.
 *
 */
public final class ProofC extends CommandBase
{
  public final static String Name = "proof";
  private Identifier ident; // identifier of  corresponding formula (may be null)
  
  /***************************************************************************
   * Create a "proof" command.
   * @param ident identifier of corresponding formula (null, if current
   * proof is processed)
   **************************************************************************/
  public ProofC(Identifier ident)
  {
    super(Name);
    this.ident = ident;
  }
  
  /****************************************************************************
   * Process command: print proof of formula respectively current proof
   ***************************************************************************/
  public void process()
  {
    if (ident == null)
    {
      Proof proof = State.getProof();
      if (proof == null)
      {
        error("there is no current proof (use \"proof <ident>\")");
        return;
      }
      proof.print();
    }
    else
    {
      FormulaSymbol symbol = getEnvironment().getFormulaSymbol(ident);
      if (symbol == null)
      {
        error("there is no formula called " + ident.toString());
        return;
      }
      if (symbol.isAxiom())
      {
        error("formula " + ident.toString() + " is an axiom");
        return;
      }
      Proof proof = symbol.getProof();
      if (proof == null)
      {
        error("formula " + ident.toString() + " does not have a proof");
        return;
      }
      proof.print();
      if (State.getProof()==null) Main.setProof(proof);
    }
  }
  
  /***************************************************************************
   * Prints text representation on out (without new line termination).
   * @param out the stream on which the text is written
   **************************************************************************/
  public void printCore(PrintWriter out)
  {
    out.print(getName());
    out.print(" ");
    ident.print(out);
  }
}