// ----------------------------------------------------------------------------
// CommandServer.java
// Server handling commands received as HTTP requests.
// $Id: CommandServer.java,v 1.4 2018/06/28 13:47:28 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Communication;

import java.io.*;
import java.net.*;

import fmrisc.ProofNavigator.*;
import fmrisc.ProofNavigator.SWT.*;

/**
 * 
 * Server handling commands received as HTTP requests.
 *
 */
public final class CommandServer extends Thread
{
  private ServerSocket serverSocket; // the socket to listen on
  
  /***************************************************************************
   * Creates a new command server (which is already started).
   *************************************************************************/
  public CommandServer()
  {
    try
    {
      serverSocket = new ServerSocket(0);
    }
    catch(IOException e)
    {
      System.out.println("Error in creating socket: " + e);
      Main.exit(-1);
    }
    start();
  }
  
  /***************************************************************************
   * Get port number on which server is listening.
   * @return the port number.
   **************************************************************************/
  public int getPortNumber()
  {
    return serverSocket.getLocalPort();
  }
  
  /****************************************************************************
   * Server listens on socket and executes received commands.
   ***************************************************************************/
  public synchronized void run()
  {
    while (true)
    {
      try
      {
        Socket socket = serverSocket.accept();
        BufferedReader reader = 
          new BufferedReader(new InputStreamReader(socket.getInputStream()));
        PrintWriter writer =
          new PrintWriter(new OutputStreamWriter(socket.getOutputStream()));
        int counter = 0;
        String request = null;
        while (true)
        {
          String line = reader.readLine();
          if (line == null)
          {
            System.out.println("Empty string read from socket.");
            Main.exit(-1);
          }
          if (counter == 0) request = line; 
          counter = counter+1;
          if (line.equals("")) break;
        }
        boolean execute = request.startsWith("GET /execute?command=");
        boolean input = request.startsWith("GET /input?pattern=");
        if (execute)
          request = request.substring(21);
        else if (input)
          request = request.substring(19);
        else
        {
          System.out.println("Error: GET expected");
          Main.exit(-1);
        }
        int end = request.indexOf(' ');
        if (end == -1)
        {
          System.out.println("Error: space character expected");
          Main.exit(-1);
        }
        request = request.substring(0, end);
        request = URLDecoder.decode(request, "UTF-8");
        if (execute)
          MainSWT.process(request);
        else if (input)
          MainSWT.enter(request);
        writer.print("HTTP/1.1 200 OK");
        writer.print("Connection: close");
        writer.flush();
        // writer.close();
      }
      catch(IOException e)
      {
        System.out.println("Error in reading from socket: " + e);
        Main.exit(-1);
      }
    }
  }
}
