// ----------------------------------------------------------------------------
// TypeSymbol.java
// Symbols in TypeTable.
// $Id: TypeSymbol.java,v 1.4 2008/10/13 09:32:00 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Semantics;

import fmrisc.ProofNavigator.Syntax.*;

/**
 * 
 * Symbols in TypeTable.
 *
 */
public final class TypeSymbol extends SymbolBase
{
  private Type type;                // the type

  /****************************************************************************
   * Construct type symbol from ident (type is set to null).
   * @param ident the identifier of the symbol
   ***************************************************************************/
  public TypeSymbol(TypeDeclIdentifier ident)
  {
    super(ident);
  }
  
  /****************************************************************************
   * Return identifier of symbol.
   * @return the symbol identifier
   ***************************************************************************/
  public TypeDeclIdentifier getTypeDeclIdentifier()
  {
    return (TypeDeclIdentifier)getIdentifier();
  }
  
  /****************************************************************************
   * Return type of symbol.
   * @return the symbol type
   ***************************************************************************/
  public Type getType()
  {
    return type;
  }
  
  /****************************************************************************
   * Set type of symbol to type.
   * @param type the symbol type.
   ***************************************************************************/
  public void setType(Type type)
  {
    this.type = type;
  }
  
  /***************************************************************************
   * Instantiate symbol with copy of denoted symbol.
   * The identifier is *not* copied from the denoted symbol.
   * @param symbol the symbol from which the instantiation is derived
   **************************************************************************/
  public void instantiate(TypeSymbol symbol)
  {
    Type type = symbol.getType();
    if (type != null) setType(Checking.canonical(type.instantiateType()));
  }
}
