// ----------------------------------------------------------------------------
// ASTVisitor.java
// Interface to visitors of abstract syntax trees.
// $Id: ASTVisitor.java,v 1.3 2008/10/13 09:32:01 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2006, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Syntax;

/**
 * 
 * Interface to visitor of abstract syntax trees.
 *
 */
public interface ASTVisitor
{
  /****************************************************************************
   * Visit an abstract syntax tree.
   * @param tree the abstract syntax tree that is visited.
   * @return the result of the visit which must be of the same type as tree; 
   * if the result is null, then an alternative result is computed based on 
   * the value of clone():
   * - if false, the result stays null.
   * - if true, the result is a clone of the tree.
   ***************************************************************************/
  public AST visit(AST tree);
  
  /****************************************************************************
   * Signal whether tree is to be cloned.
   * @return true iff tree is to be cloned, if visit returns null.
   ***************************************************************************/
  public boolean isCloned();
}
