// ----------------------------------------------------------------------------
// BitNotTerm.java
// Bit negations
// $Id: BitNotTerm.java,v 1.1 2012/10/16 15:49:36 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Syntax;

/**
 * Handling of bit negations
 */
public final class BitNotTerm extends UnaryExpression
{
  /****************************************************************************
   * construct bit negation (not term) of base term
   * @param base the base term
   ***************************************************************************/
  public BitNotTerm(Expression base)
  {
    super("~", base);
  }
  
  /***************************************************************************
   * get binding level for printing (lower numbers mean greater binding power)
   * @return the priority level
   **************************************************************************/
  public int getPriority()
  {
    return 8;
  }
  
  /***************************************************************************
   * Construct binary expression of the same kind as this expression.
   * @param base an expression.
   * @return a unary expression of the same kind as this expression
   *         with subexpression base.
   **************************************************************************/
  protected UnaryExpression construct(Expression base)
  {
    return Construct.bitNotTerm(base);
  }
  
}
