// ----------------------------------------------------------------------------
// Identifier.java
// Handling of identifiers.
// $Id: Identifier.java,v 1.16 2008/10/13 09:32:01 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Syntax;

import java.io.*;

/**
 * Handling of identifiers.
 */
public abstract class Identifier extends ASTBase 
{
  //the name of the identifier
  private String name;
  
  /****************************************************************************
   * construct identifier from name
   * @param name the text representation of the identifier
   ***************************************************************************/
  public Identifier(String name)
  {
    this.name = name;
  }
  
  /****************************************************************************
   * returns name of identifier
   * @return the identifier name
   ***************************************************************************/
  public String getName()
  {
    return name;
  }
  
  /****************************************************************************
   * set name of identifier
   * @param name the identifier name
   ***************************************************************************/
  public void setName(String name)
  {
    this.name = name;
  }
  
  /***************************************************************************
   * Prints text representation on out (without new line termination).
   * @param out the stream on which the text is written
   **************************************************************************/
  public void printCore(PrintWriter out)
  {
    out.print(name);
  }
  
  /***************************************************************************
   * Prints text representation on out (without new line termination).
   * Overrides ASTBase.print such that parentheses are never printed
   * around the number.
   * @param out the stream on which the text is written
   **************************************************************************/
  public void print(PrintWriter out)
  {
    printCore(out);
  }
  
  /****************************************************************************
   * print expression, use parentheses if priority is greater than treshold
   * @param treshold priority level of enclosing expression
   * @param out writer to print expression on
   ***************************************************************************/
  public void printPriority(int treshold, PrintWriter out)
  {
    print(out);
  }
}
