// ----------------------------------------------------------------------------
// NotEqualsFormula.java
// Handling of inequalities and exclusive disjunctions
// $Id: NotEqualsFormula.java,v 1.10 2008/10/13 09:32:01 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.ProofNavigator.Syntax;

/**
 * Handling of conjunctions
 */
public final class NotEqualsFormula extends BinaryExpression
{
  /****************************************************************************
   * construct inequality with components base1 and base2
   * @param base1 the first component
   * @param base2 the second component
   ***************************************************************************/
  public NotEqualsFormula(Expression base1, Expression base2)
  {
    super (" /= ", base1, base2);
  }
  
  /***************************************************************************
   * get binding level for printing (lower numbers mean greater binding power)
   * @return the priority level
   **************************************************************************/
  public int getPriority()
  {
    return 43;
  }
  
  /***************************************************************************
   * Construct binary expression of the same kind as this expression.
   * @param first an expression.
   * @param second an expression.
   * @return a binary expression of the same kind as this expression
   *         with subexpressions first and second.
   **************************************************************************/
  public BinaryExpression construct(Expression first, Expression second)
  {
    return Construct.notEqualsFormula(first, second);
  }
}
